@@ -1,11 +1,18 @@
+mod auth;
+mod bots;
 mod channels;
+mod dm_channels;
 mod guilds;
 mod invites;
 mod messages;
+mod moderation;
 mod roles;
 mod users;
 
+pub use auth::*;
+pub use bots::*;
 pub use channels::*;
+pub use dm_channels::*;
 pub use guilds::*;
 pub use invites::*;
 pub use messages::*;
