@@ -1,9 +1,11 @@
-/// JSON accepted for POST /api/v0/guilds/{guild_id}/roles
+use crate::perms::Permissions;
+
+/// JSON accepted for POST `/v0/guilds/{guild_id}/roles`
 #[derive(Serialize, Deserialize, Clone)]
 pub struct RoleCreateJson {
     /// Role name
     ///
-    /// Must be between 1 and 100 Unicode codepoints.
+    /// Must be between 1 and 256 Unicode codepoints.
     pub name: Option<String>,
 
     /// Role color
@@ -17,22 +19,24 @@ pub struct RoleCreateJson {
     pub position: Option<i16>,
 
     /// Role permissions
-    ///
-    /// Must be an integer between 0 and 9,223,372,036,854,775,807
-    pub permissions: Option<i64>,
+    pub permissions: Option<Permissions>,
 }
 
-/// JSON accepted for PATCH /api/v0/guilds/{guild_id}/roles/{role_id}
+/// JSON accepted for PATCH `/v0/guilds/{guild_id}/roles/{role_id}`
 #[derive(Serialize, Deserialize, Clone)]
 pub struct RoleUpdateJson {
     /// Role name
     ///
-    /// Must be between 1 and 100 Unicode codepoints.
+    /// Must be between 1 and 256 Unicode codepoints.
     pub name: Option<String>,
 
     /// Role color
     ///
-    /// Must be an integer between 0 and 16777215 (0xFFFFFF)
+    /// Must be an integer between 0 and 16777216
+    ///
+    /// Set to 16777216 to remove color
+    ///
+    /// Anything equal to or below 16777215 will be interpreted as a color
     pub color: Option<i32>,
 
     /// Role position
@@ -41,7 +45,5 @@ pub struct RoleUpdateJson {
     pub position: Option<i16>,
 
     /// Role permissions
-    ///
-    /// Must be an integer between 0 and 9,223,372,036,854,775,807
-    pub permissions: Option<i64>,
+    pub permissions: Option<Permissions>,
 }
