@@ -1,4 +1,6 @@
-/// JSON accepted for POST /api/v0/users/ (create user)
+use crate::types::Pronouns;
+
+/// JSON accepted for POST `/v0/users/` (create user)
 #[derive(Serialize, Deserialize, Clone)]
 pub struct UserCreateJson {
     /// User's preferred username.
@@ -16,12 +18,15 @@ pub struct UserCreateJson {
     /// Password must be at least one Unicode codepoint.
     /// No restrictions are applied besides that.
     pub password: String,
+
+    /// User's preferred set of pronouns.
+    pub pronouns: Option<Pronouns>,
 }
 
-/// JSON accepted for PATCH /api/v0/users/{user_id}
+/// JSON accepted for PATCH `/v0/users/{user_id}`
 #[derive(Serialize, Deserialize, Clone)]
 pub struct UserUpdateJson {
-    /// Users's preferred username.
+    /// User's preferred username.
     pub username: Option<String>,
 
     /// User's email.
@@ -39,17 +44,7 @@ pub struct UserUpdateJson {
     /// Password must be at least one Unicode codepoint.
     /// No restrictions are applied besides that.
     pub password: Option<String>,
-}
 
-/// JSON accepted for DELETE /api/v0/users/{user_id}
-#[derive(Serialize, Deserialize)]
-pub struct UserDeleteJson {
-    /// Always set this to true.
-    pub are_you_sure: bool,
-
-    /// Also always set this to true
-    pub are_you_really_sure: bool,
-
-    /// Just for fun, if you want, set this to true.
-    pub oletko_varma: Option<bool>,
+    /// User's preferred set of pronouns.
+    pub pronouns: Option<Pronouns>,
 }
