@@ -1,5 +1,6 @@
 mod auth;
 mod channel;
+mod dm_channel;
 mod embed;
 mod errors;
 mod guild;
@@ -7,12 +8,15 @@ mod invites;
 mod member;
 mod message;
 mod model_type;
+mod pronouns;
 mod role;
+mod success;
 mod user;
 mod ws;
 
 pub use auth::AuthResponse;
 pub use channel::Channel;
+pub use dm_channel::DMChannel;
 pub use embed::Embed;
 pub use errors::*;
 pub use guild::*;
@@ -20,6 +24,8 @@ pub use invites::Invite;
 pub use member::Member;
 pub use message::*;
 pub use model_type::ModelType;
+pub use pronouns::Pronouns;
 pub use role::Role;
+pub use success::SuccessJson;
 pub use user::*;
 pub use ws::WsConnectionInfo;
